@@ -54,84 +54,92 @@ void Palapeli::MainWindow::setupActions()
 	statusBarAct->setText(i18n("Show Statusbar of Puzzle Table"));
 
 	// Back to collection.
-	QAction * goCollAct = new QAction(QIcon::fromTheme(QStringLiteral("go-previous")), i18n("Back to &Collection"), this);
-	goCollAct->setToolTip(i18n("Go back to the collection to choose another puzzle"));
+	auto *goCollAct = new QAction(QIcon::fromTheme(QStringLiteral("go-previous")),
+				      i18nc("@action", "Back to &Collection"), this);
+	goCollAct->setToolTip(i18nc("@info:tooltip", "Go back to the collection to choose another puzzle"));
 	goCollAct->setEnabled(false); //because the collection is initially shown
 	actionCollection()->addAction(QStringLiteral("view_collection"), goCollAct);
 	connect(goCollAct, &QAction::triggered, m_game, &GamePlay::actionGoCollection);
 
 	// Create new puzzle (FIXME: action should have a custom icon).
-	QAction * createAct = new QAction(QIcon::fromTheme(QStringLiteral("tools-wizard")), i18n("Create &New Puzzle..."), this);
-	createAct->setToolTip(i18n("Create a new puzzle using an image file from your disk"));
+	auto *createAct = new QAction(QIcon::fromTheme(QStringLiteral("tools-wizard")),
+				      i18nc("@action", "Create &New Puzzle…"), this);
+	createAct->setToolTip(i18nc("@info:tooltip", "Create a new puzzle using an image file from your disk"));
 	KActionCollection::setDefaultShortcuts(createAct, KStandardShortcut::openNew());
 	actionCollection()->addAction(QStringLiteral("game_new"), createAct);
 	connect(createAct, &QAction::triggered, m_game, &GamePlay::actionCreate);
 
 	// Delete a puzzle.
-	QAction * deleteAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Delete Puzzle"), this);
+	auto *deleteAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
+				      i18nc("@action", "&Delete Puzzle"), this);
 	deleteAct->setEnabled(false); //will be enabled when something is selected
-	deleteAct->setToolTip(i18n("Delete the selected puzzle from your collection"));
+	deleteAct->setToolTip(i18nc("@info:tooltip", "Delete the selected puzzle from your collection"));
 	actionCollection()->addAction(QStringLiteral("game_delete"), deleteAct);
 	connect(m_game->collectionView(), &CollectionView::canDeleteChanged, deleteAct, &QAction::setEnabled);
 	connect(deleteAct, &QAction::triggered, m_game, &GamePlay::actionDelete);
 
 	// Import from file...
-	QAction * importAct = new QAction(QIcon::fromTheme(QStringLiteral("document-import")), i18n("&Import from File..."), this);
-	importAct->setToolTip(i18n("Import a new puzzle from a file into your collection"));
+	auto *importAct = new QAction(QIcon::fromTheme(QStringLiteral("document-import")),
+				      i18nc("@action", "&Import from File…"), this);
+	importAct->setToolTip(i18nc("@info:tooltip", "Import a new puzzle from a file into your collection"));
 	actionCollection()->addAction(QStringLiteral("game_import"), importAct);
 	connect(importAct, &QAction::triggered, m_game, &GamePlay::actionImport);
 
 	// Export to file...
-	QAction * exportAct = new QAction(QIcon::fromTheme(QStringLiteral("document-export")), i18n("&Export to File..."), this);
+	auto *exportAct = new QAction(QIcon::fromTheme(QStringLiteral("document-export")),
+				      i18nc("@action", "&Export to File…"), this);
 	exportAct->setEnabled(false); //will be enabled when something is selected
-	exportAct->setToolTip(i18n("Export the selected puzzle from your collection into a file"));
+	exportAct->setToolTip(i18nc("@info:tooltip", "Export the selected puzzle from your collection into a file"));
 	actionCollection()->addAction(QStringLiteral("game_export"), exportAct);
 	connect(m_game->collectionView(), &CollectionView::canExportChanged, exportAct, &QAction::setEnabled);
 	connect(exportAct, &QAction::triggered, m_game, &GamePlay::actionExport);
 
 	//Reshuffle and restart puzzle
-	QAction * restartPuzzleAct = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("&Restart Puzzle..."), this);
-	restartPuzzleAct->setToolTip(i18n("Delete the saved progress and reshuffle the pieces"));
+	auto *restartPuzzleAct = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")),
+					     i18nc("@action", "&Restart Puzzle…"), this);
+	restartPuzzleAct->setToolTip(i18nc("@info:tooltip", "Delete the saved progress and reshuffle the pieces"));
 	restartPuzzleAct->setEnabled(false); //no puzzle in progress initially
 	actionCollection()->addAction(QStringLiteral("game_restart"), restartPuzzleAct);
 	connect(restartPuzzleAct, &QAction::triggered, m_game, &GamePlay::restartPuzzle);
 	// Quit.
 	KGameStandardAction::quit (this, &QWidget::close, actionCollection());
 	// Create piece-holder.
-	QAction * createHolderAct = new QAction(i18n("&Create Piece Holder..."), this);
-	createHolderAct->setToolTip(i18n("Create a temporary holder for sorting pieces"));
+	auto *createHolderAct = new QAction(i18nc("@action", "&Create Piece Holder…"), this);
+	createHolderAct->setToolTip(i18nc("@info:tooltip", "Create a temporary holder for sorting pieces"));
 	KActionCollection::setDefaultShortcut(createHolderAct, QKeySequence(Qt::Key_C));
 	actionCollection()->addAction(QStringLiteral("move_create_holder"), createHolderAct);
         connect(createHolderAct, &QAction::triggered, m_game,
                 qOverload<>(&GamePlay::createHolder));
 
         // Delete piece-holder.
-	QAction * deleteHolderAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Delete Piece Holder"), this);
-	deleteHolderAct->setToolTip(i18n("Delete a selected temporary holder when it is empty"));
+	auto *deleteHolderAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
+					    i18nc("@action", "&Delete Piece Holder"), this);
+	deleteHolderAct->setToolTip(i18nc("@info:tooltip", "Delete a selected temporary holder when it is empty"));
 	KActionCollection::setDefaultShortcut(deleteHolderAct, QKeySequence(Qt::Key_D));
 	actionCollection()->addAction(QStringLiteral("move_delete_holder"), deleteHolderAct);
 	connect(deleteHolderAct, &QAction::triggered, m_game, &GamePlay::deleteHolder);
 
 	// Select all pieces in a piece-holder.
-	QAction * selectAllAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-select-all")), i18n("&Select All in Holder"), this);
-	selectAllAct->setToolTip(i18n("Select all pieces in a selected piece holder"));
+	auto *selectAllAct = new QAction(QIcon::fromTheme(QStringLiteral("edit-select-all")),
+					 i18nc("@action", "&Select All in Holder"), this);
+	selectAllAct->setToolTip(i18nc("@info:tooltip", "Select all pieces in a selected piece holder"));
 	KActionCollection::setDefaultShortcut(selectAllAct, QKeySequence(Qt::Key_A));
 	actionCollection()->addAction(QStringLiteral("move_select_all"), selectAllAct);
 	connect(selectAllAct, &QAction::triggered, m_game, &GamePlay::selectAll);
 
 	// Rearrange a selected piece-holder or selected pieces in any view.
-	QAction * rearrangeAct = new QAction(i18n("&Rearrange Pieces"), this);
-	rearrangeAct->setToolTip(i18n("Rearrange all pieces in a selected piece holder or selected pieces in any window"));
+	auto *rearrangeAct = new QAction(i18nc("@action", "&Rearrange Pieces"), this);
+	rearrangeAct->setToolTip(i18nc("@info:tooltip", "Rearrange all pieces in a selected piece holder or selected pieces in any window"));
 	KActionCollection::setDefaultShortcut(rearrangeAct, QKeySequence(Qt::Key_R));
 	actionCollection()->addAction(QStringLiteral("move_rearrange"), rearrangeAct);
 	connect(rearrangeAct, &QAction::triggered, m_game, &GamePlay::rearrangePieces);
 
 	// Toggle puzzle-preview.
 	bool  isVisible = Settings::puzzlePreviewVisible();
-	const QString text = i18nc("Preview is a noun here", "&Preview");
-	KToggleAction* togglePreviewAct = new KToggleAction(QIcon::fromTheme(QStringLiteral("view-preview")), text, this);
-	togglePreviewAct->setIconText(i18nc("Preview is a noun here", "Preview"));
-	togglePreviewAct->setToolTip(i18n("Show or hide the image of the completed puzzle"));
+	auto *togglePreviewAct = new KToggleAction(QIcon::fromTheme(QStringLiteral("view-preview")),
+						   i18nc("@option:check", "Show Preview"), this);
+	togglePreviewAct->setIconText(i18nc("@option:check Preview is a noun here", "Preview"));
+	togglePreviewAct->setToolTip(i18nc("@info:tooltip", "Show or hide the image of the completed puzzle"));
 	actionCollection()->addAction(QStringLiteral("view_preview"), togglePreviewAct);
 	togglePreviewAct->setEnabled(false);
 	togglePreviewAct->setChecked(isVisible);
@@ -145,7 +153,7 @@ void Palapeli::MainWindow::setupActions()
 	KStandardAction::zoomOut(m_game, &GamePlay::actionZoomOut,
 						actionCollection());
 	// Settings: enable messages that the user marked "Do not show again".
-	QAction * enableMessagesAct = new QAction(i18n("Enable All Messages"), this);
+	auto *enableMessagesAct = new QAction(i18nc("@action", "Enable All Messages"), this);
 	actionCollection()->addAction(QStringLiteral("enable_messages"), enableMessagesAct);
 	connect(enableMessagesAct, &QAction::triggered, this, &MainWindow::enableMessages);
 }
